{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}
{% block modal-body-right %}
<h3>{% trans "Description:" %}</h3>
<p>{% trans "Modify reserved, type, on_maintenance and control_attributes of a host." %}</p>
{% endblock %}
