{% load i18n sizeformat parse_date %}
  <div class="detail">
        <h4>{% trans "Notification Detail" %}</h4>
        <hr class="header_rule">
        <dl class="dl-horizontal">
            <dt>{% trans "Notification UUID" %}</dt>
            <dd>{{ notification.notification_uuid }}</dd>
            <dt>{% trans "Source Host UUID" %}</dt>
            <dd>{{ notification.source_host_uuid }}</dd>
            <dt>{% trans "Type" %}</dt>
            <dd>{{ notification.type }}</dd>
            <dt>{% trans "Status" %}</dt>
            <dd>{{ notification.status }}</dd>
            <dt>{% trans "Generated Time" %}</dt>
            <dd>{{ notification.generated_time|parse_isotime }}</dd>
            <dt>{% trans "Created At" %}</dt>
            <dd>{{ notification.created_at|parse_isotime }}</dd>
            <dt>{% trans "Updated At" %}</dt>
            <dd>{{ notification.updated_at|parse_isotime }}</dd>
            <dt>{% trans "Payload" %}</dt>
            <dd>{{ notification.payload }}</dd>
        </dl>
  </div>
